diff --git a/wp-includes/user.php b/wp-includes/user.php
index e0e0f8b09f..9af3b02a75 100644
--- a/wp-includes/user.php
+++ b/wp-includes/user.php
@@ -427,7 +427,7 @@ function setup_userdata($user_id = '') {
*
include - User IDs to include.
* exclude - User IDs to exclude.
* multi - Default is 'false'. Whether to skip the ID attribute on the 'select' element.
* show - Default is 'display_name'. User table column to display.
* echo - Default is '1'. Whether to display or retrieve content.
* selected - Which User ID is selected.
* name - Default is 'user'. Name attribute of select element.
@@ -493,7 +493,8 @@ function wp_dropdown_users( $args = '' ) {
foreach ( (array) $users as $user ) {
$user->ID = (int) $user->ID;
$_selected = $user->ID == $selected ? " selected='selected'" : '';
- $output .= "\t\n";
+ $display = !empty($user->$show) ? $user->$show : '('. $user->user_login . ')';
+ $output .= "\t\n";
}
$output .= "";
@@ -427,7 +427,7 @@ function setup_userdata($user_id = '') {
* exclude - User IDs to exclude.
* multi - Default is 'false'. Whether to skip the ID attribute on the 'select' element.
- * show - Default is 'display_name'. User table column to display.
+ * show - Default is 'display_name'. User table column to display. If the selected item is empty then the user_login will be displayed in parentesis
* echo - Default is '1'. Whether to display or retrieve content.
* selected - Which User ID is selected.